EpayPlatformInterface class abstract

An abstract class that defines the interface for platform-specific implementations of the EpayPlatform. Platform-specific code should implement the methods defined in this class to interact with the native platform.

Inheritance
  • Object
  • PlatformInterface
  • EpayPlatformInterface
Implementers

Constructors

EpayPlatformInterface()
Constructs an EpayPlatformInterface instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkInternetConnection() Future<List<INetResult>>
Checks the internet connection status on the native platform.
getMethodChannel() MethodChannel
Gets the MethodChannel used for communication with the native platform.
initiateTransaction(String paymentUrl, String referrer) Future<String?>
Initiates a payment transaction with the provided paymentUrl on the native platform.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance EpayPlatformInterface
The default instance of EpayPlatformInterface to use.
getter/setter pair

Constants

channelName → const String
The method channel name used for communication between Flutter and the native platform.
methodChannelCheckInternetConnection → const String
The method channel name for checking the internet connection on the native platform.
methodChannelInitiateTransaction → const String
The method channel name for initiating a transaction on the native platform.
methodChannelStartMonitoring → const String
The method channel name for starting network monitoring on iOS.
methodChannelStopMonitoring → const String
The method channel name for stopping network monitoring on iOS.