checkInternetConnection method

Future<List<INetResult>> checkInternetConnection()

Checks the internet connection status on the native platform.

This method must be implemented by platform-specific subclasses to check the internet connection status and return a list of INetResult objects based on the result.

Implementation

Future<List<INetResult>> checkInternetConnection() {
  throw UnimplementedError('internetConnection(_) has not been implemented.');
}