initiateTransaction method

Future<String?> initiateTransaction({
  1. required String paymentUrl,
  2. required String referrer,
})

Initiates a transaction by passing the payment URL to the native platform.

The provided paymentUrl and referrer is sent to the native platform to start a payment transaction. The method returns a string result, which can be used for feedback or toast messages.

Implementation

Future<String?> initiateTransaction(
    {required String paymentUrl, required String referrer}) {
  return EpayPlatformInterface.instance
      .initiateTransaction(paymentUrl, referrer);
}